EXPORTS
	??1CSpeechRecognitionUtility@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CSpeechRecognitionUtility::~CSpeechRecognitionUtility(void)
	?AddPronunciation@CSpeechRecognitionUtility@@QAEHKKKAAK@Z @ 2 NONAME ; public: int __thiscall CSpeechRecognitionUtility::AddPronunciation(unsigned long,unsigned long,unsigned long,unsigned long &)
	?AddRule@CSpeechRecognitionUtility@@QAEHKKKAAK@Z @ 3 NONAME ; public: int __thiscall CSpeechRecognitionUtility::AddRule(unsigned long,unsigned long,unsigned long,unsigned long &)
	?Cancel@CSpeechRecognitionUtility@@QAEXXZ @ 4 NONAME ; public: void __thiscall CSpeechRecognitionUtility::Cancel(void)
	?CommitChanges@CSpeechRecognitionUtility@@QAEHXZ @ 5 NONAME ; public: int __thiscall CSpeechRecognitionUtility::CommitChanges(void)
	?CreateGrammar@CSpeechRecognitionUtility@@QAEHAAK@Z @ 6 NONAME ; public: int __thiscall CSpeechRecognitionUtility::CreateGrammar(unsigned long &)
	?CreateLexicon@CSpeechRecognitionUtility@@QAEHAAK@Z @ 7 NONAME ; public: int __thiscall CSpeechRecognitionUtility::CreateLexicon(unsigned long &)
	?CreateModelBank@CSpeechRecognitionUtility@@QAEHAAK@Z @ 8 NONAME ; public: int __thiscall CSpeechRecognitionUtility::CreateModelBank(unsigned long &)
	?E32Dll@@YAHW4TDllReason@@@Z @ 9 NONAME ; int __cdecl E32Dll(enum TDllReason)
	?EndRecSession@CSpeechRecognitionUtility@@QAEHXZ @ 10 NONAME ; public: int __thiscall CSpeechRecognitionUtility::EndRecSession(void)
	?GetAllClientGrammarIDs@CSpeechRecognitionUtility@@QAEHAAV?$RArray@K@@@Z @ 11 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetAllClientGrammarIDs(class RArray<unsigned long> &)
	?GetAllClientLexiconIDs@CSpeechRecognitionUtility@@QAEHAAV?$RArray@K@@@Z @ 12 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetAllClientLexiconIDs(class RArray<unsigned long> &)
	?GetAllClientModelBankIDs@CSpeechRecognitionUtility@@QAEHAAV?$RArray@K@@@Z @ 13 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetAllClientModelBankIDs(class RArray<unsigned long> &)
	?GetAllGrammarIDs@CSpeechRecognitionUtility@@QAEHAAV?$RArray@K@@@Z @ 14 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetAllGrammarIDs(class RArray<unsigned long> &)
	?GetAllLexiconIDs@CSpeechRecognitionUtility@@QAEHAAV?$RArray@K@@@Z @ 15 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetAllLexiconIDs(class RArray<unsigned long> &)
	?GetAllModelBankIDs@CSpeechRecognitionUtility@@QAEHAAV?$RArray@K@@@Z @ 16 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetAllModelBankIDs(class RArray<unsigned long> &)
	?GetAllModelIDs@CSpeechRecognitionUtility@@QAEHKAAV?$RArray@K@@@Z @ 17 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetAllModelIDs(unsigned long,class RArray<unsigned long> &)
	?GetAllPronunciationIDs@CSpeechRecognitionUtility@@QAEHKAAV?$RArray@K@@@Z @ 18 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetAllPronunciationIDs(unsigned long,class RArray<unsigned long> &)
	?GetAllRuleIDs@CSpeechRecognitionUtility@@QAEHKAAV?$RArray@K@@@Z @ 19 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetAllRuleIDs(unsigned long,class RArray<unsigned long> &)
	?GetAvailableStorage@CSpeechRecognitionUtility@@QAEHAAH@Z @ 20 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetAvailableStorage(int &)
	?GetEngineProperties@CSpeechRecognitionUtility@@QAEHABV?$RArray@H@@AAV2@@Z @ 21 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetEngineProperties(class RArray<int> const &,class RArray<int> &)
	?GetModelCount@CSpeechRecognitionUtility@@QAEHKAAH@Z @ 22 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetModelCount(unsigned long,int &)
	?GetRuleValidity@CSpeechRecognitionUtility@@QAEHKKAAH@Z @ 23 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetRuleValidity(unsigned long,unsigned long,int &)
	?GetUtteranceDuration@CSpeechRecognitionUtility@@QAEHKKAAVTTimeIntervalMicroSeconds32@@@Z @ 24 NONAME ; public: int __thiscall CSpeechRecognitionUtility::GetUtteranceDuration(unsigned long,unsigned long,class TTimeIntervalMicroSeconds32 &)
	?LoadEngineParameters@CSpeechRecognitionUtility@@QAEHABV?$RArray@H@@0@Z @ 25 NONAME ; public: int __thiscall CSpeechRecognitionUtility::LoadEngineParameters(class RArray<int> const &,class RArray<int> const &)
	?LoadGrammar@CSpeechRecognitionUtility@@QAEHK@Z @ 26 NONAME ; public: int __thiscall CSpeechRecognitionUtility::LoadGrammar(unsigned long)
	?LoadLexicon@CSpeechRecognitionUtility@@QAEHK@Z @ 27 NONAME ; public: int __thiscall CSpeechRecognitionUtility::LoadLexicon(unsigned long)
	?LoadModels@CSpeechRecognitionUtility@@QAEHK@Z @ 28 NONAME ; public: int __thiscall CSpeechRecognitionUtility::LoadModels(unsigned long)
	?NewL@CSpeechRecognitionUtility@@SAPAV1@AAVMSpeechRecognitionUtilityObserver@@VTUid@@@Z @ 29 NONAME ; public: static class CSpeechRecognitionUtility * __cdecl CSpeechRecognitionUtility::NewL(class MSpeechRecognitionUtilityObserver &,class TUid)
	?NewLC@CSpeechRecognitionUtility@@SAPAV1@AAVMSpeechRecognitionUtilityObserver@@VTUid@@@Z @ 30 NONAME ; public: static class CSpeechRecognitionUtility * __cdecl CSpeechRecognitionUtility::NewLC(class MSpeechRecognitionUtilityObserver &,class TUid)
	?PlayUtterance@CSpeechRecognitionUtility@@QAEHKK@Z @ 31 NONAME ; public: int __thiscall CSpeechRecognitionUtility::PlayUtterance(unsigned long,unsigned long)
	?Recognize@CSpeechRecognitionUtility@@QAEHAAVCSDClientResultSet@@@Z @ 32 NONAME ; public: int __thiscall CSpeechRecognitionUtility::Recognize(class CSDClientResultSet &)
	?Record@CSpeechRecognitionUtility@@QAEHVTTimeIntervalMicroSeconds32@@@Z @ 33 NONAME ; public: int __thiscall CSpeechRecognitionUtility::Record(class TTimeIntervalMicroSeconds32)
	?RemoveGrammar@CSpeechRecognitionUtility@@QAEHK@Z @ 34 NONAME ; public: int __thiscall CSpeechRecognitionUtility::RemoveGrammar(unsigned long)
	?RemoveLexicon@CSpeechRecognitionUtility@@QAEHK@Z @ 35 NONAME ; public: int __thiscall CSpeechRecognitionUtility::RemoveLexicon(unsigned long)
	?RemoveModel@CSpeechRecognitionUtility@@QAEHKK@Z @ 36 NONAME ; public: int __thiscall CSpeechRecognitionUtility::RemoveModel(unsigned long,unsigned long)
	?RemoveModelBank@CSpeechRecognitionUtility@@QAEHK@Z @ 37 NONAME ; public: int __thiscall CSpeechRecognitionUtility::RemoveModelBank(unsigned long)
	?RemovePronunciation@CSpeechRecognitionUtility@@QAEHKK@Z @ 38 NONAME ; public: int __thiscall CSpeechRecognitionUtility::RemovePronunciation(unsigned long,unsigned long)
	?RemoveRule@CSpeechRecognitionUtility@@QAEHKK@Z @ 39 NONAME ; public: int __thiscall CSpeechRecognitionUtility::RemoveRule(unsigned long,unsigned long)
	?SetAudioPriority@CSpeechRecognitionUtility@@QAEHHHHH@Z @ 40 NONAME ; public: int __thiscall CSpeechRecognitionUtility::SetAudioPriority(int,int,int,int)
	?SetEventHandler@CSpeechRecognitionUtility@@QAEXPAVMSpeechRecognitionUtilityObserver@@@Z @ 41 NONAME ; public: void __thiscall CSpeechRecognitionUtility::SetEventHandler(class MSpeechRecognitionUtilityObserver *)
	?StartRecSession@CSpeechRecognitionUtility@@QAEHW4TRecognitionMode@@@Z @ 42 NONAME ; public: int __thiscall CSpeechRecognitionUtility::StartRecSession(enum TRecognitionMode)
	?Train@CSpeechRecognitionUtility@@QAEHKAAK@Z @ 43 NONAME ; public: int __thiscall CSpeechRecognitionUtility::Train(unsigned long,unsigned long &)
	?UnloadRule@CSpeechRecognitionUtility@@QAEHKK@Z @ 44 NONAME ; public: int __thiscall CSpeechRecognitionUtility::UnloadRule(unsigned long,unsigned long)

